@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: crypto-api
-version: 0.6.1
-id: crypto-api-0.6.1-441f8b227b136ba1febefb2d9e4c0949
+version: 0.8
+id: crypto-api-0.8-05b728f3d677abca6e90bce525286739
 
 license: BSD3
 copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>, Francisco Blas Izquierdo Riera (klondike) (see AUTHORS)
@@ -9,10 +9,7 @@ maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
 stability: stable
 homepage: http://trac.haskell.org/crypto-api/wiki
 package-url:
-description: A generic interface for cryptographic operations,
-             platform independent quality RNG, property tests
-             and known-answer tests (KATs) for common algorithms,
-             and a basic benchmark infrastructure.
+description: A generic interface for cryptographic operations (hashes, ciphers, randomness).
              Maintainers of hash and cipher implementations are
              encouraged to add instances for the classes defined
              in Crypto.Classes.  Crypto users are similarly
@@ -26,25 +23,27 @@ author: Thomas DuBuisson <thomas.dubuisson@gmail.com>, Francisco Blas Izquierdo
 pkgpath: security/hs-crypto-api
 exposed: True
 exposed-modules: Crypto.Classes Crypto.Types Crypto.HMAC
-                 Crypto.Modes System.Crypto.Random Crypto.Random Crypto.Padding
+                 Crypto.Modes Crypto.Random Crypto.Padding
 hidden-modules: Crypto.Util Crypto.CPoly
-import-dirs: /usr/local/lib/ghc/crypto-api-0.6.1
-library-dirs: /usr/local/lib/ghc/crypto-api-0.6.1
-hs-libraries: HScrypto-api-0.6.1
+import-dirs: /usr/local/lib/ghc/crypto-api-0.8
+library-dirs: /usr/local/lib/ghc/crypto-api-0.8
+hs-libraries: HScrypto-api-0.8
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-e1ba2d2213b66179f3e0c901a27d3a96
-         bytestring-0.9.1.10-2da7b519f76934c0e733bf92c23382ec
-         cereal-0.3.0.0-ee33e7a9312912eef09d2af1b20190e8
-         largeword-1.0.0-51321644574ac8da7a5c254f698d9e07
-         tagged-0.2-7caf964ebb614f24b61729c6e1006b72
+depends: array-0.3.0.2-143060371bda4ff52c270d1067551fe8
+         base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
+         bytestring-0.9.1.10-d11caeadd9605139e1a59850ce083826
+         cereal-0.3.0.0-c17ac2a70f89323d10af6f3ac87760ec
+         entropy-0.2.1-de629404e9cf90edf577cc323c76bad0
+         largeword-1.0.0-c39497709d633542d290e92c0c11e3a4
+         tagged-0.2-4db34a1a28b200ea54bef8eab1247bdb
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-crypto-api-0.6.1/html/crypto-api.haddock
-haddock-html: /usr/local/share/doc/hs-crypto-api-0.6.1/html
+haddock-interfaces: /usr/local/share/doc/hs-crypto-api-0.8/html/crypto-api.haddock
+haddock-html: /usr/local/share/doc/hs-crypto-api-0.8/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
